#!/bin/ksh

############################## INIT  SECTION #########################
# NAME          :sysstats.sh
#
# DESCRIPTION   : The script purpose is to show the Resource Utilization statistics of System 
#
#
# Changed history :
#    date                 by                     change
#--------------+------------------------+--------------------------------
# 02/08/11   Hiko Davis           Modified for use with ksh
#--------------+------------------------+--------------------------------
######################################################################
##### MAIN #####
set -A vmststarr `vmstat 1 2|tail -1|awk '{printf("%d %d %d %d %d %d %d %lld %lld %lld %.0f %.0f %.0f %.0f %.0f %.0f",$1,$2,$5,$6,$7,$8,$9,$11,$12,$13,$14,$15,$16,$17,$18,$19)}'`
set -A svmonarr `svmon -G | awk '/memory/ {printf("%d %d %d %d %d",$2/256,$3/256,$4/256,$5/256,$6/256)}'`
totmem=`svmon -G | awk '/memory/ {printf("%.0f",$2/256)}'`
inuse=`svmon -G | awk '/memory/ {printf("%.0f",$3/256)}'`
free=`svmon -G | awk '/memory/ {printf("%.0f",$4/256)}'`
pinmem=`svmon -G | awk '/memory/ {printf("%.0f",$5/256)}'`
virtmem=`svmon -G | awk '/memory/ {printf("%.0f",$6/256)}'`
fsused=`vmstat -v | awk '/file pages/ {printf("%.0f",$1/256)}'`
memusdpr=`expr ${svmonarr[1]} \* 100 / ${svmonarr[0]}`
fsusedpr=`expr $fsused \* 100 / ${svmonarr[0]}`
pssyusper=`expr $memusdpr - $fsusedpr`
pgsptot=`svmon -G | awk '/pg space/ {printf("%.0f",$3/256)}'`
pgspused=`svmon -G | awk '/pg space/ {printf("%.0f",$4/256)}'`
pgspuspr=`expr $pgspused \* 100 / $pgsptot`
lcpu=`lparstat|head -2|awk '{print $6}'|awk -F"=" '{print $2}'|tail -1|sed 's/^ *//;s/ *$//'`
phymem=`lparstat|head -2|awk '{print $7}'|awk -F"=" '{print $2}'| sed 's/MB//'|awk '{print $1}'|tail -1|sed 's/^ *//;s/ *$//'`
entcap=`lparstat|head -2|awk '{print $9}'|awk -F"=" '{print $2}'|tail -1|sed 's/^ *//;s/ *$//'`
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Kernel Threads:Threads in Run Queue\" value=\"${vmststarr[0]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Kernel Threads:Threads in Wait Queue\" value=\"${vmststarr[1]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Paging:Pages In/Out per sec\" value=\"${vmststarr[2]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Paging:Pages In/s\" value=\"${vmststarr[3]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Paging:Pages Out/s\" value=\"${vmststarr[4]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Paging:Pages Freed/s\" value=\"${vmststarr[5]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Paging:Pages Scanned/s\" value=\"${vmststarr[6]}\"/>"
echo "<metric type=\"LongCounter\" name=\"System Resource Utilization|System:Interrupts/s\" value=\"${vmststarr[7]}\"/>"
echo "<metric type=\"LongCounter\" name=\"System Resource Utilization|System:System calls/s\" value=\"${vmststarr[8]}\"/>"
echo "<metric type=\"LongCounter\" name=\"System Resource Utilization|System:Context Switches/s\" value=\"${vmststarr[9]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:User %\" value=\"${vmststarr[10]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:System %\" value=\"${vmststarr[11]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:Idle %\" value=\"${vmststarr[12]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:Wait for IO  %\" value=\"${vmststarr[13]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:Physical Processor Util %\" value=\"${vmststarr[14]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|CPU:Entitlement Util %\" value=\"${vmststarr[15]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Total Memory (MB)\" value=\"${svmonarr[0]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Used Memory (MB)\" value=\"${svmonarr[1]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Free Memory (MB)\" value=\"${svmonarr[2]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Pinned Memory (MB)\" value=\"${svmonarr[3]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Active Virtual Memory (MB)\" value=\"${svmonarr[4]}\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Filesystem Memory (MB)\" value=\"$fsused\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Memory Utilization (%)\" value=\"$memusdpr\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:FS Memory Utilization (%)\" value=\"$fsusedpr\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:System Process Memory Util (%)\" value=\"$pssyusper\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Paging Space Total (MB)\" value=\"$pgsptot\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Paging Space Used (MB)\" value=\"$pgspused\"/>"
echo "<metric type=\"IntCounter\" name=\"System Resource Utilization|Memory:Paging Space Utilization (%)\" value=\"$pgspuspr\"/>"
echo "<metric type=\"StringEvent\" name=\"System Resource Utilization|Config:Logical CPUs\" value=\"$lcpu\"/>"
echo "<metric type=\"StringEvent\" name=\"System Resource Utilization|Config:Physical Memory (MB)\" value=\"$phymem\"/>"
echo "<metric type=\"StringEvent\" name=\"System Resource Utilization|Config:Entitlement Capacity\" value=\"$entcap\"/>"
